/**
 * @file
 * A Backbone Model for the edit_ui block.
 */

(function (Drupal, Backbone) {

  "use strict";

  /**
   * Backbone model for the edit_ui block.
   */
  Drupal.editUiBlock.BlockModel = Backbone.Model.extend({
    defaults: {
      plugin_id: false,
      region: false,
      weight: 0,
      label: '',
      html_id: 0,
      block: null,
      isVisible: false,
      isDragging: false
    },

    /**
     * {@inheritdoc}
     */
    urlRoot: Drupal.url('edit-ui/block'),

    /**
     * {@inheritdoc}
     */
    initialize: function (options) {
      this.on('startDrag', this.startDrag);
      this.on('stopDrag', this.stopDrag);
    },

    /**
     * {@inheritdoc}
     */
    toJSON: function() {
      return {
        region: this.get('region'),
        weight: this.get('weight')
      };
    },

    /**
     * Set block visible state.
     */
    visible: function() {
      this.set({isVisible: true});
    },

    /**
     * Set block element.
     *
     * @param {jQuery} $block
     *   Block element.
     */
    setBlock: function($block) {
      this.set({block: $block});
    },

    /**
     * Set block dragging state.
     */
    startDrag: function() {
      this.set({isDragging: true});
    },

    /**
     * Set block not dragging state.
     */
    stopDrag: function() {
      this.set({isDragging: false});
    },

    /**
     * Drop block in a new region.
     *
     * @param {string} region
     *   The region identifier.
     * @param {number} weight
     *   The weight of the block within the region.
     */
    drop: function(region, weight) {
      this.set({
        region: region,
        weight: weight + 1
      });
      if (!this.isNew()) {
        this.save();
      }
    }
  });

}(Drupal, Backbone));
