/**
 * @file
 * Drupal behavior for the edit_ui blocks.
 */

(function (Drupal, $) {
  "use strict";

  /**
   * Drupal edit_ui block behavior.
   */
  Drupal.behaviors.editUiBlock = {
    attach: function(context, settings) {
      if (!this.isInitialized) {
        this.isInitialized = true;

        // Init block collection.
        var collection = Drupal.editUiBlock.collections.blockCollection = new Drupal.editUiBlock.BlockCollection();

        // Init views.
        Drupal.editUiBlock.views.bodyVisualView = new Drupal.editUiBlock.BodyVisualView({
          collection: collection
        });

        // Init block view list.
        Drupal.editUiBlock.views.blockVisualViews = [];

        // Global variable for new block.
        Drupal.editUiBlock.models.newBlockModel = null;
      }
    }
  };

  /**
   * edit_ui block Backbone objects.
   */
  Drupal.editUiBlock = {
    // A hash of View instances.
    views: {},
    // A hash of Collection instances.
    collections: {},
    // A hash of Model instances.
    models: {}
  };

  /**
   * Add new AJAX command called after the block as been created in the backend.
   */
  Drupal.AjaxCommands.prototype.editUiAddNewBlockToCollection = function(ajax, response, status) {
    var region;

    if (Drupal.editUiBlock.models.newBlockModel instanceof Drupal.editUiBlock.BlockModel) {
      Drupal.editUiBlock.models.newBlockModel.set({
        id: response['id'],
        plugin_id: response['plugin_id'],
        label: response['label'],
        html_id: response['html_id']
      });
      region = Drupal.editUiRegion.collections.regionCollection.findWhere({
        region: Drupal.editUiBlock.models.newBlockModel.get('region')
      });
      region.trigger('addBlock', region, Drupal.editUiBlock.models.newBlockModel, response.content);
      Drupal.editUiBlock.models.newBlockModel = null;
    }
  };

})(Drupal, jQuery);
