/**
 * @file
 *
 * Drupal behavior for the edit_ui regions.
 */

(function (Drupal, $) {
  "use strict";

  /**
   * Drupal edit_ui region behavior.
   */
  Drupal.behaviors.editUiRegion = {
    attach: function(context, settings) {
      if (!this.isInitialized) {
        this.isInitialized = true;

        // Init empty data.
        Drupal.editUiRegion.collections.regionCollection = new Drupal.editUiRegion.RegionCollection();
        Drupal.editUiRegion.models.regionModel = [];
        Drupal.editUiRegion.views.regionVisualView = [];

        // Fill data.
        $('.js-edit-ui__region', context).each(function(index, el) {
          var model, view;
          var $el = $(el);
          var region = $el.data('edit-ui-region');

          // Init region model.
          model = new Drupal.editUiRegion.RegionModel({
            region: region
          });
          Drupal.editUiRegion.models.regionModel.push(model);

          // Init region view.
          view = new Drupal.editUiRegion.RegionVisualView({
            model: model,
            el: $el
          });
          Drupal.editUiRegion.views.regionVisualView.push(view);

          // Add model to collection.
          Drupal.editUiRegion.collections.regionCollection.add(model);
        });
      }
    }
  };

  /**
   * edit_ui region Backbone objects.
   */
  Drupal.editUiRegion = {
    // A hash of View instances.
    views: {},
    // A hash of Model instances.
    models: {},
    // A hash of Collection instances.
    collections: {}
  };

})(Drupal, jQuery);
