/**
 * @file
 * Drupal behavior for the edit_ui blocks.
 */

(function (Drupal, $) {
  "use strict";

  /**
   * edit_ui block Backbone objects.
   */
  Drupal.editUiUtils = {

    /**
     * Get mouse or touch position.
     *
     * @param {Event} event
     *   The event object.
     */
    getPosition: function(event) {
      var position = {x: 0, y: 0};

      if (event.type.indexOf('touch') === 0) {
        position = {
          x: event.originalEvent.changedTouches[0].pageX,
          y: event.originalEvent.changedTouches[0].pageY
        };
      }
      else {
        position = {
          x: event.pageX,
          y: event.pageY
        };
      }

      return position;
    },

    /**
     * call native Drupal AjaxCommands.
     */
    callAjaxCommands: function(model, response, options) {
      var commands = new Drupal.AjaxCommands();

      for (var i in response) {
        if (response.hasOwnProperty(i) && response[i].command && commands[response[i].command]) {
          commands[response[i].command]({getEffect: Drupal.ajax.prototype.getEffect}, response[i]);
        }
      }
    }

  };

  /**
   * Command to add new status messages.
   */
  Drupal.AjaxCommands.prototype.editUiAddMessage = function(ajax, response, status) {
    var $content = $('<div class="js-edit-ui__messages"></div>').html(response.content);

    // Hide and insert.
    $content.hide();
    $content.insertBefore('.region-messages .edit-ui__region-block');

    // Show and hide old messages.
    $content.fadeIn(response.speed, function() {
      $('.js-edit-ui__messages').not(this).fadeOut(response.speed);
    });
  };

})(Drupal, jQuery);
