/**
 * @file
 * A Backbone Collection for the edit_ui region.
 */

(function (Drupal, Backbone) {

  "use strict";

  /**
   * Backbone collection for the edit_ui region.
   */
  Drupal.editUiRegion.RegionCollection = Backbone.Collection.extend({
    model: Drupal.editUiRegion.RegionModel,

    /**
     * Initiliaze regions data.
     */
    init: function() {
      this.models.forEach(function(region) {
        region.trigger('init');
      });
    },

    /**
     * Find hovered region.
     *
     * @param {number} x
     *   Mouse left position.
     * @param {number} y
     *   Mouse top position.
     */
    drag: function(x, y) {
      if (this.activeRegion) {
        // Trigger dragIn event only to active region.
        this.activeRegion.trigger('dragIn', this.activeRegion, {x: x, y: y});
      }
      else {
        // Trigger dragOut event to all regions.
        this.models.forEach(function(region) {
          region.trigger('dragOut', region, {x: x, y: y});
        });
      }
    },

    /**
     * Drop block.
     *
     * @param {Drupal.editUiBlock.BlockModel} block
     *   The dropped block.
     * @param {number} x
     *   Mouse left position.
     * @param {number} y
     *   Mouse top position.
     */
    drop: function(block, x, y) {
      if (this.activeRegion) {
        this.activeRegion.trigger('drop', this.activeRegion, block, {x: x, y: y});
      }

      // Re-init default states.
      this.setActiveRegion();
    },

    /**
     * Set or unset active region.
     *
     * @param {Drupal.editUiRegion.RegionModel|null} region
     *   Region to activate.
     */
    setActiveRegion: function(region) {
      if (region instanceof Drupal.editUiRegion.RegionModel) {
        if (this.activeRegion) {
          this.activeRegion.deactivate();
        }
        this.activeRegion = region;
        this.activeRegion.activate();
      }
      else if (this.activeRegion) {
        this.activeRegion.deactivate();
        this.activeRegion = null;
      }
    }
  });

}(Drupal, Backbone));
