/**
 * @file
 * A Backbone Model for the edit_ui region.
 */

(function (Drupal, Backbone) {

  "use strict";

  /**
   * Backbone model for the edit_ui region.
   */
  Drupal.editUiRegion.RegionModel = Backbone.Model.extend({
    defaults: {
      region: '',
      block: null,
      isActive: false
    },

    /**
     * {@inheritdoc}
     */
    initialize: function (options) {
      this.set({region: options.region});
    },

    /**
     * Set region active state.
     */
    activate: function() {
      this.set({isActive: true});
    },

    /**
     * Set region not active state.
     */
    deactivate: function() {
      this.set({isActive: false});
    },

    /**
     * Set region edit_ui block.
     *
     * @param {jQuery} $block
     *   Edit_ui block.
     */
    setBlock: function($block) {
      this.set({block: $block});
    }
  });

}(Drupal, Backbone));
