/**
 * @file
 * A Backbone Model for the edit_ui toolbar.
 */

(function (Drupal, Backbone) {

  "use strict";

  /**
   * Backbone model for the edit_ui toolbar.
   */
  Drupal.editUiToolbar.ToolbarModel = Backbone.Model.extend({
    defaults: {
      isOpen: false,
      topOffset: 0,
      toolbarModel: null
    },

    /**
     * {@inheritdoc}
     */
    initialize: function (options) {
      this.fetch();
      this.listenTo(Drupal.toolbar.models.toolbarModel, 'change:offsets', this.setTopOffset);
    },

    /**
     * {@inheritdoc}
     */
    sync: function(method, model, options) {
      var resp;

      switch (method) {
        case 'read':
          resp = JSON.parse(localStorage.getItem('Drupal.editUi'));
          model.set(resp);
          break;

        case 'create':
        case 'update':
          resp = model;
          localStorage.setItem('Drupal.editUi', JSON.stringify(resp));
          break;

        case 'delete':
          resp = model;
          localStorage.removeItem('Drupal.editUi');
          break;
      }

      options.success(resp);
    },

    /**
     * {@inheritdoc}
     */
    toJSON: function() {
      return {isOpen: this.get('isOpen')};
    },

    /**
     * Toggle toolbar.
     */
    toggle: function() {
      this.save({isOpen: !this.get('isOpen')});
    },

    /**
     * Set top offset.
     */
    setTopOffset: function() {
      var topOffset = Drupal.toolbar.models.toolbarModel.get('offsets').top;
      this.save({topOffset: topOffset});
    }
  });

}(Drupal, Backbone));
