<?php

/**
 * @file
 * Contains \Drupal\edit_ui\Ajax\AddBlockCommand.
 */

namespace Drupal\edit_ui\Ajax;

use Drupal\Core\Ajax\CommandInterface;
use Drupal\Core\Ajax\CommandWithAttachedAssetsTrait;
use Drupal\block\Entity\Block;
use Symfony\Component\EventDispatcher\EventDispatcherInterface;
use Drupal\block\Event\BlockContextEvent;
use Drupal\block\Event\BlockEvents;
use Drupal\Component\Utility\Html;

/**
 * Provides an AJAX command for showing the messages.
 */
class AddBlockCommand implements CommandInterface {

  use CommandWithAttachedAssetsTrait;

  /**
   * The block entity.
   *
   * @var Drupal\block\Entity\Block
   */
  protected $block;

  /**
   * The renderable content.
   *
   * @var array
   */
  protected $content = array();

  /**
   * Constructs an InsertCommand object.
   *
   * @return \Drupal\block\Entity\Block $block
   *   The block entity.
   */
  public function __construct(Block $block) {
    $this->block = $block;
  }

  /**
   * Implements Drupal\Core\Ajax\CommandInterface:render().
   */
  public function render() {
    $entity_manager = \Drupal::entityManager();
    $event_dispatcher = \Drupal::service('event_dispatcher');

    $contexts = $event_dispatcher->dispatch(BlockEvents::ACTIVE_CONTEXT, new BlockContextEvent())->getContexts();
    if ($this->block->setContexts($contexts)->access('view')) {
      $this->content = $entity_manager->getViewBuilder($this->block->getEntityTypeId())->view($this->block);
    }

    return array(
      'command'   => 'editUiAddNewBlockToCollection',
      'id'        => $this->block->getOriginalId(),
      'plugin_id' => $this->block->getPluginId(),
      'region'    => $this->block->getRegion(),
      'weight'    => $this->block->getWeight(),
      'label'     => $this->block->label(),
      'html_id'   => Html::getId('block-' . $this->block->getOriginalId()),
      'content'   => $this->getRenderedContent(),
    );
  }

}
