<?php

/**
 * @file
 * Contains \Drupal\edit_ui\Element\EditUiToolbar.
 */

namespace Drupal\edit_ui\Element;
use Drupal\Core\Block\BlockManagerInterface;
use Drupal\Core\Render\Element\RenderElement;
use Drupal\Component\Utility\String;
use Drupal\Core\Url;
use Drupal\Component\Serialization\Json;

/**
 * Provides a render element for the edit UI toolbar.
 *
 * Allow to dynamically add bloc type to website.
 *
 * @RenderElement("edit-ui-toolbar")
 */
class EditUiToolbar extends RenderElement {

  /**
   * {@inheritdoc}
   */
  public function getInfo() {
    return array(
      '#pre_render' => array(
        array(get_class($this), 'preRenderEditUiToolbar'),
      ),
      '#attached' => array(
        'library' => array(
          'edit_ui/edit-ui.toolbar',
          'edit_ui/edit-ui.region',
          'edit_ui/edit-ui.block',
        ),
      ),
    );
  }

  /**
   * Builds the Toolbar as a structured array ready for drupal_render().
   *
   * Since building the toolbar takes some time, it is done just prior to
   * rendering to ensure that it is built only if it will be displayed.
   *
   * @param array $element
   *   A renderable array.
   *
   * @return array
   *   A renderable array.
   */
  public static function preRenderEditUiToolbar(array $element) {
    $element['toolbar']['#type'] = 'container';
    $element['toolbar']['#attributes'] = array(
      'id' => 'edit-ui__toolbar',
      'class' => array('toolbar', 'edit-ui__toolbar', 'hidden'),
    );

    $element['toolbar']['title'] = array(
      '#type' => 'container',
      '#markup' => '<h3>' . t('Place blocks') . '</h3>',
      '#attributes' => array(
        'class' => array('entity-meta-header', 'edit-ui__toolbar-title'),
      ),
    );

    $element['toolbar']['filter'] = array(
      '#type' => 'search',
      '#title' => t('Filter'),
      '#title_display' => 'invisible',
      '#size' => 30,
      '#placeholder' => t('Filter by block name'),
      '#attributes' => array(
        'class' => array('block-filter-text'),
        'data-element' => '.entity-meta',
        'title' => t('Enter a part of the block name to filter by.'),
      ),
    );

    $element['toolbar']['list']['#type'] = 'container';
    $element['toolbar']['list']['#attributes']['class'][] = 'entity-meta';

    $plugins = \Drupal::service('plugin.manager.block')->getSortedDefinitions();
    $i = 0;

    foreach ($plugins as $plugin_id => $plugin_definition) {
      $category = String::checkPlain($plugin_definition['category']);
      $category_key = 'category-' . $category;
      if (!isset($element['toolbar']['list'][$category_key])) {
        $element['toolbar']['list'][$category_key] = array(
          '#type' => 'details',
          '#title' => $category,
          '#open' => TRUE,
          'content' => array(
            '#theme' => 'links',
            '#links' => array(),
            '#attributes' => array(
              'class' => array(
                'block-list',
              ),
            ),
          ),
        );
      }

      $element['toolbar']['list'][$category_key]['content']['#links'][$plugin_id] = array(
        'title' => $plugin_definition['admin_label'],
        'url' => Url::fromRoute('block.admin_add', array(
          'plugin_id' => $plugin_id,
          'theme' => \Drupal::theme()->getActiveTheme()->getName(),
        )),
        'attributes' => array(
          'class' => array('block-filter-text-source', 'edit-ui__add-block', 'js-edit-ui__add-block'),
          'id' => 'edit-ui__add-block--' . $i
        ),
      );
      $i++;
    }

    return $element;
  }

}
