<?php

/**
 * @file
 * Contains \Drupal\edit_ui\EventSubscriber\EditUiPageDisplayVariantSubscriber.
 */

namespace Drupal\edit_ui\EventSubscriber;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Drupal\Core\Render\PageDisplayVariantSelectionEvent;
use Drupal\Core\Render\RenderEvents;

/**
 * Selects the edit_ui page display variant.
 *
 * @see \Drupal\edit_ui\Plugin\DisplayVariant\EditUiPageVariant
 */
class EditUiPageDisplayVariantSubscriber implements EventSubscriberInterface {

  /**
   * Selects the edit_ui page display variant.
   *
   * @param \Drupal\Core\Render\PageDisplayVariantSelectionEvent $event
   *   The event to process.
   */
  public function onSelectPageDisplayVariant(PageDisplayVariantSelectionEvent $event) {
    if (\Drupal::currentUser()->hasPermission('access edit_ui toolbar')
     && !\Drupal::service('router.admin_context')->isAdminRoute()) {
      $event->setPluginId('edit_ui_page');
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[RenderEvents::SELECT_PAGE_DISPLAY_VARIANT][] = array('onSelectPageDisplayVariant');
    return $events;
  }

}
