<?php

/**
 * @file
 * Contains \Drupal\edit_ui\Plugin\DisplayVariant\EditUiPageVariant.
 */

namespace Drupal\edit_ui\Plugin\DisplayVariant;

use Drupal\block\Plugin\DisplayVariant\BlockPageVariant;
use Drupal\Component\Utility\Html;
use Drupal\Core\Block\MainContentBlockPluginInterface;

/**
 * Provides a page display variant that add decorations for edit_ui interface.
 *
 * @PageDisplayVariant(
 *   id = "edit_ui_page",
 *   admin_label = @Translation("Page with all regions and blocks")
 * )
 */
class EditUiPageVariant extends BlockPageVariant {

  /**
   * {@inheritdoc}
   */
  public function build() {
    $theme = \Drupal::config('system.theme')->get('default');
    $main_content_block_displayed = FALSE;
    $build = [
      '#cache' => [
        'tags' => $this->blockListCacheTags,
      ],
    ];

    // Add edit_ui region block at the beginning of each visible regions.
    $visible_regions = system_region_list($theme, REGIONS_VISIBLE);
    foreach (array_keys($visible_regions) as $region) {
      $build[$region]['edit_ui_region_block'] = array(
        '#type' => 'container',
        '#attributes' => array(
          'class' => array('edit-ui__region', 'js-edit-ui__region'),
          'data-edit-ui-region' => $region,
        ),
        'highlight' => array(
          '#type' => 'html_tag',
          '#tag' => 'div',
          '#attributes' => array(
            'class' => array('edit-ui__region-highlight'),
          ),
        ),
        'label' => array(
          '#type' => 'html_tag',
          '#tag' => 'span',
          '#value' => $visible_regions[$region],
          '#attributes' => array(
            'class' => array('edit-ui__region-label'),
          ),
        ),
      );
    }

    // Append classic blocks in regions.
    $contexts = $this->getActiveBlockContexts();
    foreach ($this->blockRepository->getVisibleBlocksPerRegion($contexts) as $region => $blocks) {
      foreach ($blocks as $key => $block) {
        $block_plugin = $block->getPlugin();
        if ($block_plugin instanceof MainContentBlockPluginInterface) {
          $block_plugin->setMainContent($this->mainContent);
          $main_content_block_displayed = TRUE;
        }
        $build[$region][$key] = $this->blockViewBuilder->view($block);
      }
      $build[$region]['#sorted'] = TRUE;
    }

    // Add edit_ui filling block at the end of each visible regions.
    $visible_regions = system_region_list($theme, REGIONS_VISIBLE);
    foreach (array_keys($visible_regions) as $region) {
      $build[$region]['edit_ui_filling_block'] = array(
        '#type' => 'html_tag',
        '#tag' => 'div',
        '#attributes' => array(
          'class' => array('edit-ui__region-block'),
        ),
      );
    }

    if (!$main_content_block_displayed) {
      $build['content']['system_main'] = $this->mainContent;
    }

    return $build;
  }

}
